# Rustic AI LiteLLM

This module offers seamless integration with various LLMs through [LiteLLM](https://docs.litellm.ai/docs/), simplifying the use of language models within [Rustic AI](https://www.rustic.ai/) guilds.

## Installing

```shell
pip install rusticai-litellm
```
**Note:** It depends on [rusticai-core](https://pypi.org/project/rusticai-core/)

## Building from Source

```shell
poetry install --with dev
poetry build
```